pub struct ParallelHash256 { /* private fields */ }Expand description
ParallelHash256 implementation
Implementations
Sourceimpl ParallelHash256
impl ParallelHash256
Sourcepub fn new(custom: &[u8], blocksize: usize) -> Self
pub fn new(custom: &[u8], blocksize: usize) -> Self
Creates a new ParallelHash instance with the given customization string and block size
Sourcepub fn finalize(self, output: &mut [u8]) -> Option<()>
pub fn finalize(self, output: &mut [u8]) -> Option<()>
Finalize with specified output length.
output.len() must not exceed MAX_SP800185_FIXED_OUTPUT_BYTES. For longer
output, use Self::xof.
Returns None if output.len() is greater than
MAX_SP800185_FIXED_OUTPUT_BYTES.
Sourcepub fn finalize_with_length(self, output_len: usize) -> Option<Vec<u8>>
pub fn finalize_with_length(self, output_len: usize) -> Option<Vec<u8>>
Finalize with specified output length and return as Vec.
Returns None if output_len is greater than MAX_SP800185_FIXED_OUTPUT_BYTES.
For longer output, use Self::xof.
Sourcepub fn xof(self) -> ParallelHash256Reader
pub fn xof(self) -> ParallelHash256Reader
Returns an XOF reader for variable-length output.
SP 800-185 encodes XOF mode with right_encode(0) (output bit length zero) before
squeezing.
This consumes self and finalizes the sponge; you cannot call Self::update
afterward on this value.