CustomizedInit

Trait CustomizedInit 

pub trait CustomizedInit: Sized {
    // Required method
    fn new_customized(customization: &[u8]) -> Self;
}
Trait for hash functions with customization string for domain separation.

Required Methods

fn new_customized(customization: &[u8]) -> Self

Create new hasher instance with the given customization string.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CustomizedInit for CShake128

Source

fn new_customized(customization: &[u8]) -> CShake128

Source

impl CustomizedInit for CShake256

Source

fn new_customized(customization: &[u8]) -> CShake256

Source

impl CustomizedInit for CShake128Core

Source

fn new_customized(customization: &[u8]) -> CShake128Core

Source

impl CustomizedInit for CShake256Core

Source

fn new_customized(customization: &[u8]) -> CShake256Core

Implementors